@@ -33,6 +33,8 @@
 #include <QDomDocument>
 #include <QIODevice>
 #include <QFile>
+#include <QFileInfo>
+#include <QDir>
 
 #include <KDebug>
 
@@ -226,6 +228,13 @@ void CourseResource::sync()
     root.appendChild(unitListElement);
 
     // write back to file
+    QFileInfo info(path().directory());    // create directories if necessary
+    if (!info.exists()) {
+        kDebug() << "create xml output file directory, not existing";
+        QDir dir;
+        dir.mkpath(path().directory());
+    }
+
     //TODO port to KSaveFile
     QFile file;
     file.setFileName(path().toLocalFile());
@@ -310,16 +319,20 @@ QObject * CourseResource::resource()
         return d->m_courseResource;
     }
 
-    if (!path().isLocalFile()) {
-        kWarning() << "Cannot open course file at " << path().toLocalFile() << ", aborting.";
-        return 0;
+    // if file does not exist, create new course
+    QFileInfo info(d->m_path.toLocalFile());
+    if (!info.exists()) {
+        d->m_courseResource = new Course(this);
+        d->m_courseResource->setId(d->m_identifier);
+        d->m_courseResource->setTitle(d->m_title);
+        return d->m_courseResource;
     }
 
+    // load existing file
     QXmlSchema schema = loadXmlSchema("course");
     if (!schema.isValid()) {
         return 0;
     }
-
     QDomDocument document = loadDomDocument(path(), schema);
     if (document.isNull()) {
         kWarning() << "Could not parse document " << path().toLocalFile() << ", aborting.";
