@@ -217,6 +217,8 @@ void MainWindow::showSettingsDialog()
     connect(dialog, SIGNAL(accepted()), appearenceDialog, SLOT(saveSettings()));
     connect(dialog, SIGNAL(accepted()), SLOT(updateTrainingPhraseFont()));
     connect(dialog, SIGNAL(accepted()), SLOT(updateKcfgUseContributorResources()));
+    connect(dialog, SIGNAL(finished()), soundDialog, SLOT(stopPlaying()));
+    connect(dialog, SIGNAL(finished()), soundDialog, SLOT(stopRecord()));
 
     dialog->exec();
 }
